#
# spec file for package clusterctl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version_git_major 1
%define version_git_minor 8

Name:           clusterctl
Version:        1.10.3
Release:        1.1
Summary:        CLI tool to handle the lifecycle of a Cluster API management cluster
License:        Apache-2.0
URL:            https://github.com/kubernetes-sigs/cluster-api
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23
BuildRequires:  zsh

%description
The clusterctl CLI tool handles the lifecycle of a Cluster API management
cluster.

The clusterctl command line interface is specifically designed for providing a
simple “day 1 experience” and a quick start with Cluster API. It automates
fetching the YAML files defining provider components and installing them.

Additionally it encodes a set of best practices in managing providers, that
helps the user in avoiding mis-configurations or in managing day 2 operations
such as upgrades.

Below you can find a list of main clusterctl commands:

* clusterctl init: Initialize a management cluster.
* clusterctl upgrade plan: Provide a list of recommended target versions for
  upgrading Cluster API providers in a management cluster.
* clusterctl upgrade apply: Apply new versions of Cluster API core and providers
  in a management cluster.
* clusterctl delete: Delete one or more providers from the management cluster.
* clusterctl generate: cluster Generate templates for creating workload
  clusters.
* clusterctl generate yaml: Process yaml using clusterctl’s yaml processor.
* clusterctl get kubeconfig: Gets the kubeconfig file for accessing a workload
  cluster.
* clusterctl move: Move Cluster API objects and all their dependencies between
  management clusters.
* clusterctl alpha rollout: Manages the rollout of Cluster API resources. For
  example: MachineDeployments.

Avoiding GitHub rate limiting

While using providers hosted on GitHub, clusterctl is calling GitHub API which
are rate limited; for normal usage free tier is enough but when using
clusterctl extensively users might hit the rate limit.

To avoid rate limiting for the public repos set the GITHUB_TOKEN environment
variable. To generate a token follow this documentation. The token only needs
repo scope for clusterctl.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X sigs.k8s.io/cluster-api/version.gitVersion=v%{version} \
   -X sigs.k8s.io/cluster-api/version.gitCommit=${COMMIT_HASH} \
   -X sigs.k8s.io/cluster-api/version.gitTreeState=clean \
   -X sigs.k8s.io/cluster-api/version.gitMajor=%{version_git_major} \
   -X sigs.k8s.io/cluster-api/version.gitMinor=%{version_git_minor} \
   -X sigs.k8s.io/cluster-api/version.gitReleaseCommit=${COMMIT_HASH} \
   -X sigs.k8s.io/cluster-api/version.buildDate=$BUILD_DATE" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Wed Jun 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.10.3:
  * fix govulncheck security scan
  * [release-1.10] clusterctl: accept upper case version
    (#12321)
* Wed May 21 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.10.2:
  * build: bump golang.org/x/net to 0.38
  * 📖 Update clusterctl version to v1.10.x in quick start
* Tue Apr 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.10.1:
  * New Features
  - Testing: Bump Kubernetes in tests to v1.33.0 and claim
    support for v1.33 (#12105)
  * Bug Fixes
  - Bootstrap: Make
    joinConfiguration.discovery.bootstrapToken.token optional
    (#12136)
  * Others
  - Dependency: Bump cert-manager to v1.17.1 (#12127)
* Fri Apr 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.10.0:
  Large update, see the full changelog here:
  https://github.com/kubernetes-sigs/cluster-api/releases/tag/v1.10.0
  * clusterctl-related changes:
  - New providers in clusterctl:
  - Addon providers: fleet (#11806)
  - Infrastructure providers: OpenNebula (#11835), Harvester
    (#11477), Huawei Cloud (#11861)
  - CRD migration: Deprecated clusterctl upgrade CRD storage
    version migration for providers (#11889)
  - ClusterClass: Add e2e tests & clusterctl changes for cross-ns
    CC ref (#11395)
  - ClusterClass: Clusterctl move support for a cross namespace
    ClusterClass reference (#11649)
  - clusterctl: Add addon provider fleet to registry (#11806)
  - clusterctl: Add OpenNebula infrastructure provider to
    clusterctl (#11835)
  - clusterctl: Add support for clusterctl gitlab auth (#11792)
  - e2e: Test n-3 clusterctl upgrade (#11884)
  - util: Add CRD migrator, deprecate clusterctl upgrade CRD
    storage version migration (#11889)
  - clusterctl: Clusterctl upgrade hangs for a time on CRD
    migration when new version contains a number of new CRDs
    (#12002)
  - clusterctl: Fix multiline Ready condition in clusterctl
    describe for v1beta2 (#11781)
  - clusterctl: send delete request before removing finalizers
    (#11814)
  - clusterctl: Add Infrastructure provider Harvester (#11477)
  - clusterctl: Add support infrastructure provider for Huawei
    Cloud (#11861)
  - clusterctl: Bump cert-manager to v1.16.3 (#11699)
  - clusterctl: Change k0smotron repo location (#11872)
  - clusterctl: Fix fallback to overrides directory in home when
    there is no overrides directory in XDG directory (#11824)
  - clusterctl: Properly indent multiline lists in clusterctl
    describe (#11508)
  - clusterctl: Remove OCNE providers (#11830)
  - e2e: Add clusterctl describe to E2E artifacts (#11966)
  - e2e: Add optional ClusterctlVariables to QuickStartSpecInput
    (#11780)
  - e2e: Add retry to clusterctl UpgradeWithBinary (#11478)
  - e2e: Write clusterctl describe to ginkgowriter on failure
    (#11983)
  * Dependencies added
  - cloud.google.com/go/auth/oauth2adapt: v0.2.6
  - cloud.google.com/go/auth: v0.13.0
  - cloud.google.com/go/monitoring: v1.21.2
  - github.com/GoogleCloudPlatform/opentelemetry-operations-go/detectors/gcp: v1.25.0
  - github.com/GoogleCloudPlatform/opentelemetry-operations-go/exporter/metric: v0.48.1
  - github.com/GoogleCloudPlatform/opentelemetry-operations-go/internal/resourcemapping: v0.48.1
  - github.com/go-viper/mapstructure/v2: v2.2.1
  - github.com/planetscale/vtprotobuf: 0393e58
  - go.opentelemetry.io/contrib/detectors/gcp: v1.29.0
  - go.opentelemetry.io/otel/sdk/metric: v1.29.0
  * Dependencies changed
  - cel.dev/expr: v0.15.0 → v0.18.0
  - cloud.google.com/go/compute/metadata: v0.3.0 → v0.6.0
  - cloud.google.com/go/iam: v1.1.5 → v1.2.2
  - cloud.google.com/go/storage: v1.35.1 → v1.49.0
  - cloud.google.com/go: v0.112.1 → v0.116.0
  - github.com/Azure/go-ansiterm: d185dfc → 306776e
  - github.com/cncf/xds/go: 555b57e → b4127c9
  - github.com/coredns/corefile-migration: v1.0.24 → v1.0.26
  - github.com/cpuguy83/go-md2man/v2: v2.0.4 → v2.0.6
  - github.com/emicklei/go-restful/v3: v3.12.1 → v3.12.2
  - github.com/envoyproxy/go-control-plane: v0.12.0 → v0.13.1
  - github.com/envoyproxy/protoc-gen-validate: v1.0.4 → v1.1.0
  - github.com/evanphx/json-patch/v5: v5.9.0 → v5.9.11
  - github.com/fsnotify/fsnotify: v1.7.0 → v1.8.0
  - github.com/go-openapi/jsonpointer: v0.19.6 → v0.21.0
  - github.com/go-openapi/swag: v0.22.4 → v0.23.0
  - github.com/golang/glog: v1.2.1 → v1.2.2
  - github.com/google/btree: v1.0.1 → v1.1.3
  - github.com/google/cel-go: v0.20.1 → v0.22.0
  - github.com/google/go-cmp: v0.6.0 → v0.7.0
  - github.com/google/pprof: d1b30fe → 40e02aa
  - github.com/google/s2a-go: v0.1.7 → v0.1.8
  - github.com/googleapis/enterprise-certificate-proxy:
    v0.3.2 → v0.3.4
  - github.com/googleapis/gax-go/v2: v2.12.3 → v2.14.1
  - github.com/gorilla/websocket: v1.5.0 → v1.5.3
  - github.com/gregjones/httpcache: 9cad4c3 → 901d907
  - github.com/hashicorp/golang-lru: v0.5.4 → v0.5.1
  - github.com/jessevdk/go-flags: v1.4.0 → v1.6.1
  - github.com/jonboulle/clockwork: v0.2.2 → v0.4.0
  - github.com/moby/spdystream: v0.4.0 → v0.5.0
  - github.com/onsi/ginkgo/v2: v2.22.0 → v2.23.3
  - github.com/onsi/gomega: v1.36.0 → v1.36.3
  - github.com/pelletier/go-toml/v2: v2.2.2 → v2.2.3
  - github.com/pkg/sftp: v1.13.6 → v1.13.7
  - github.com/sagikazarmark/locafero: v0.4.0 → v0.7.0
  - github.com/spf13/afero: v1.11.0 → v1.12.0
  - github.com/spf13/cast: v1.7.0 → v1.7.1
  - github.com/spf13/cobra: v1.8.1 → v1.9.1
  - github.com/spf13/pflag: v1.0.5 → v1.0.6
  - github.com/spf13/viper: v1.19.0 → v1.20.0
  - github.com/stoewer/go-strcase: v1.2.0 → v1.3.0
  - github.com/stretchr/objx: v0.5.2 → v0.5.0
  - github.com/stretchr/testify: v1.9.0 → v1.10.0
  - github.com/xiang90/probing: 43a291a → a49e3df
  - go.etcd.io/bbolt: v1.3.9 → v1.3.11
  - go.etcd.io/etcd/api/v3: v3.5.17 → v3.5.20
  - go.etcd.io/etcd/client/pkg/v3: v3.5.17 → v3.5.20
  - go.etcd.io/etcd/client/v2: v2.305.13 → v2.305.16
  - go.etcd.io/etcd/client/v3: v3.5.17 → v3.5.20
  - go.etcd.io/etcd/pkg/v3: v3.5.13 → v3.5.16
  - go.etcd.io/etcd/raft/v3: v3.5.13 → v3.5.16
  - go.etcd.io/etcd/server/v3: v3.5.13 → v3.5.16
  - go.opentelemetry.io/contrib/instrumentation/google.golang.org/grpc/otelgrpc:
    v0.53.0 → v0.54.0
  - go.opentelemetry.io/contrib/instrumentation/net/http/otelhttp:
    v0.53.0 → v0.54.0
  - go.opentelemetry.io/otel/metric: v1.28.0 → v1.29.0
  - go.opentelemetry.io/otel/sdk: v1.28.0 → v1.29.0
  - go.opentelemetry.io/otel/trace: v1.28.0 → v1.29.0
  - go.opentelemetry.io/otel: v1.28.0 → v1.29.0
  - golang.org/x/crypto: v0.29.0 → v0.36.0
  - golang.org/x/mod: v0.21.0 → v0.23.0
  - golang.org/x/net: v0.31.0 → v0.37.0
  - golang.org/x/oauth2: v0.24.0 → v0.28.0
  - golang.org/x/sync: v0.9.0 → v0.12.0
  - golang.org/x/sys: v0.27.0 → v0.31.0
  - golang.org/x/term: v0.26.0 → v0.30.0
  - golang.org/x/text: v0.20.0 → v0.23.0
  - golang.org/x/time: v0.5.0 → v0.8.0
  - golang.org/x/tools: v0.26.0 → v0.30.0
  - golang.org/x/xerrors: 04be3eb → 5ec99f8
  - gomodules.xyz/jsonpatch/v2: v2.4.0 → v2.5.0
  - google.golang.org/api: v0.171.0 → v0.215.0
  - google.golang.org/appengine: v1.6.8 → v1.6.7
  - google.golang.org/genproto/googleapis/api: 5315273 → e6fa225
  - google.golang.org/genproto/googleapis/rpc: f6361c8 → 3abc09e
  - google.golang.org/genproto: 012b6fc → e639e21
  - google.golang.org/grpc: v1.65.1 → v1.67.3
  - google.golang.org/protobuf: v1.35.1 → v1.36.5
  - k8s.io/api: v0.31.3 → v0.32.3
  - k8s.io/apiextensions-apiserver: v0.31.3 → v0.32.3
  - k8s.io/apimachinery: v0.31.3 → v0.32.3
  - k8s.io/apiserver: v0.31.3 → v0.32.3
  - k8s.io/client-go: v0.31.3 → v0.32.3
  - k8s.io/cluster-bootstrap: v0.31.3 → v0.32.3
  - k8s.io/code-generator: v0.31.3 → v0.32.3
  - k8s.io/component-base: v0.31.3 → v0.32.3
  - k8s.io/gengo/v2: 51d4e06 → 2b36238
  - k8s.io/kms: v0.31.3 → v0.32.3
  - k8s.io/kube-openapi: 70dd376 → 32ad38e
  - k8s.io/utils: 18e509b → 3ea5e8c
  - sigs.k8s.io/apiserver-network-proxy/konnectivity-client:
    v0.30.3 → v0.31.0
  - sigs.k8s.io/controller-runtime: v0.19.3 → v0.20.4
  - sigs.k8s.io/json: bc3834c → 9aa6b5e
  - sigs.k8s.io/structured-merge-diff/v4: v4.4.1 → v4.4.2
  * Dependencies removed
  - cloud.google.com/go/compute: v1.24.0
  - cloud.google.com/go/firestore: v1.15.0
  - cloud.google.com/go/longrunning: v0.5.5
  - github.com/armon/go-metrics: v0.4.1
  - github.com/googleapis/google-cloud-go-testing: 1c9a4c6
  - github.com/hashicorp/consul/api: v1.28.2
  - github.com/hashicorp/errwrap: v1.1.0
  - github.com/hashicorp/go-cleanhttp: v0.5.2
  - github.com/hashicorp/go-hclog: v1.5.0
  - github.com/hashicorp/go-immutable-radix: v1.3.1
  - github.com/hashicorp/go-multierror: v1.1.1
  - github.com/hashicorp/go-rootcerts: v1.0.2
  - github.com/hashicorp/hcl: v1.0.0
  - github.com/hashicorp/serf: v0.10.1
  - github.com/imdario/mergo: v0.3.13
  - github.com/klauspost/compress: v1.17.2
  - github.com/magiconair/properties: v1.8.7
  - github.com/mitchellh/go-homedir: v1.1.0
  - github.com/mitchellh/mapstructure: v1.5.0
  - github.com/nats-io/nats.go: v1.34.0
  - github.com/nats-io/nkeys: v0.4.7
  - github.com/nats-io/nuid: v1.0.1
  - github.com/sagikazarmark/crypt: v0.19.0
  - github.com/sagikazarmark/slog-shim: v0.1.0
  - gopkg.in/ini.v1: v1.67.0
* Fri Apr 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.9.7:
  CLI-related changes from the changelog
  https://github.com/kubernetes-sigs/cluster-api/releases/tag/v1.9.7
  * Bug Fixes
  - clusterctl: Clusterctl upgrade hangs for a time on CRD
    migration when new version contains a number of new CRDs
    (#12003)
  * Dependencies
  - github.com/coredns/corefile-migration: v1.0.25 → v1.0.26
* Tue Mar 18 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.9.6:
  CLI-related changes from the changelog
  https://github.com/kubernetes-sigs/cluster-api/releases/tag/v1.9.6
  * New Features
  - clusterctl: Add OpenNebula infrastructure provider to
    clusterctl (#11886)
  * Others
  - clusterctl: Add support infrastructure provider for Huawei
    Cloud (#11876)
  - clusterctl: Change k0smotron repo location (#11888)
* Wed Feb 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.9.5:
  CLI-related changes from the changelog
  https://github.com/kubernetes-sigs/cluster-api/releases/tag/v1.9.5
  * Implement clusterctl move support for cross-ns CC
  * Add ClusterctlVariables to QuickStartSpecInput
* Wed Jan 22 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.9.4:
  * Update CAPO quick-start docs
  * More comments
  * More feedback
  * Address comments
  * Fix unit test
  * Add k/v pairs describing the overall status of the control
    plane
  * Improve Machine create and delete logs
  * [release-1.9] 🌱 inmemory: fix watch to continue serving based
    on resourceVersion parameter (#11710)
  * clustercache: Prevent concurrent map read/write when creating a
    cache
  * Address comments
  * Improve Machine remediation logs
  * Sort providers A-Z
  * Adds RKE2 to list of providers
  * Also patch external refs if the UID differs
  * Bump coredns support in docs
  * Bump github.com/coredns/corefile-migration to v1.0.25
  * patch: Call patchHelper only if necessary when reconciling
    external refs
  * patchHelper: call toUnstructured only if necessary
  * KCP: stop recreating logger for etcd client
  * Fix resync in in-memory provider
  * Fix formatting of blocking lifecycle hook condition message
  * Reduce log level of noisy logs in ExtensionConfig and topology
    Cluster controller
  * [release-1.9] 🌱 Add Infrastructure provider Harvester (#11653)
  * Fix broken links in the release team handbooks
  * Bump to controller-runtime v0.19.4
  * Bump envtest to v1.32.0
  * Fix log messages in Cluster set status code + some minor unit
    test fixes
  * fix a link for Cluster API videos and tutorials
  * Machine: sort list of pre-drain hooks for stable condition
    messages
* Mon Dec 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.3:
  * Bump to golang.org/x/net v0.23.0
  * Export runtime.Client interface and cache package
* Sat Dec 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.2:
  * [release-1.9] 🌱 Reconcile topology only when necessary
    (#11606)
  * [release-1.9] 🌱 Improve KCP scale up when using failure
    domains (#11604)
  * [release-1.9] 🌱 add TypedAll, ResourceIsUnchanged and
    TypedResourceIsUnchanged predicates (#11603)
  * Cache DiscoveryVariables calls
* Wed Dec 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.1:
  * Update version page
  * CONTRIBUTING.md fix dead links
  * Bump golang.org/x/net
  * Bump golang.org/x/crypto
  * book: fix versions.md for v1.32
  * Set v1.7 EOL date and update CoreDns version table
  * Allow scalability to have custom deletion timeout
  * Bump default kind image to v1.32.0
  * machine: remove solved todo comment
  * Bump Kubernetes in tests to v1.32.0 and claim support for v1.32
  * 📖 Update clusterctl version to v1.9.x in quick start
  * 📖 add release 1.8 book link
* Wed Dec 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.9.0:
  Full changelog is available here:
  https://github.com/kubernetes-sigs/cluster-api/releases/tag/v1.9.0
  * New providers in clusterctl: Canonical (#11337), Nutanix
    (#11135), Vultr (#11091)
  * New features:
  - clusterctl: Add support for v1beta2 conditions to clusterctl
    describe (#11277)
  - clusterctl: Allow user to suppress API warnings (#11149)
  - clusterctl: Suppress "finalizer name" API warnings in "move"
    command (#11173)
  * Bugfixes
  - clusterctl: Ensure move uses mutated metadata when updating a
    target object (#10957)
  - clusterctl: Fix: considers objects in kube-system for
    cert-manager to avoid upgrading twice (#11351)
  - clusterctl: Handle a nil mutator by returning an error, not
    panicking (#10951)
* Wed Dec 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.6:
  * seedling: Add retry to clusterctl `UpgradeWithBinary`
  * Bump go to v1.22.10
  * Bump github.com/coredns/corefile-migration to v1.0.24
  * 🌱Update controller-runtime to v0.18.6
  * seedling: Add dry-run CreateOrUpdate call in clusterctl upgrade
    e2e tests
  * fix: do not reassign slice as it is used in different methods
  * fix: removes use of slices.DeleteFunc because it zeros the
    elements and doesn't remove those from obj list
  * fix: considers objects in kube-system for cert-manager to avoid
    upgrading twice
  * 🌱 [release-1.8] clusterctl: add nutanix ipam & runtime
    extensions providers
  * Uplift Go version to v1.22.9
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.5:
  * Bump Go to v1.22.8 version
  * KCP: Skip validation if CoreDNS migration library supports an
    upgrade if skip CoreDNS is set
  * bump cert-manager to 1.16.1
  * seedling: Remove json logging replacement in e2e test config
  * test/framework: allow to include arbitrary types when dumping
    resources
  * fix: incorrect name used in kustomize path
  * kcp: consider all machines for setting .status.version
  * 🌱 test: add PreWaitForControlplaneToBeUpgraded to
    ClusterUpgradeConformanceSpec (#11145)
  * Update mailing list
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.4:
  * Bump cert manager to v1.16.0
  * switch to using ECR mirror for trivy DB repo
  * add cacheSyncPeriod option to ClusterCacheTracker
  * pr-verify: use env var for passing the PR title
  * Update RKE2 provider URL
  * :seedling: test/e2e: decrease concurrency
  * [release-1.8] :seedling: Add vultr infrastructure provider
    (#11217)
  * test/framework: GetCAPIResources should warn on rbac issues
  * 🌱 test/framework: allow users to modify cache.Options
  * [release-1.8] 🌱 machine: prevent error spamming for
    NodeOutdatedTaint if objects are not found (#11199)
  * Reduce verbosity of logs when calling Runtime Extensions
  * clusterclass: fix nil pointer for empty workers in webhook
  * 📖 Drop v1.5 column, set v1.6 to EOL in versions.md
  * hack: fix the shell used when running pr-verify
  * [release-1.8] 🌱 replace kubebuilder-release-tools with new
    workflow (#11167)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.3:
  * Make KCP pre-terminate hook more robust
  * Bump to Go 1.22.7
  * Add more documentation about the KCP pre-terminate hook
  * test/e2e: increase concurrency
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.2:
  * [release-1.8] 🐛 KCP: remove etcd member in pre-terminate hook
    (#11136)
  * book: document how to use Lima on macOS for development
  * 📖 Move Control Plane contracts doc to right chapter
  * re-add /finalizers subresource RBAC
  * test: Bump autoscaler to v1.31.0
  * 📖 Fix CAPZ redirection links in quick-start page
  * sorted labels and annotations in alphabatical order
  * [release-1.8] 🌱 test: improve autoscale tests for to/from zero
    and running autoscaler in bootstrap cluster (#11093)
  * update cert-manager to 1.15.3
  * Always declare try-or-die-command function in
    kubeadm-bootstrap-script.sh
  * Bump envtest in Makefile to v1.31.0
  * Bump kind to v0.24.0
  * docs: fix broken link
  * Update clusterctl version to v1.8.x in quick start
  * Set 1.6 EOL date
* Wed Aug 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.1:
  * Bump Kubernetes in tests to v1.31.0 and claim support for v1.31
  * Improve clusterctl client config logic & error message
  * Update controller-runtime dependency to v0.18.5
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.0:
  Changelog too big to include in toto, please check it here
  https://github.com/kubernetes-sigs/cluster-api/releases/tag/v1.8.0
  * Breaking Changes
  - ClusterClass: Adjust CC & Cluster controller to block on
    variable conflicts, deprecate definitionFrom (#10841)
  * Highlights
  - New providers in clusterctl: IONOS Cloud (#10767), Linode
    (#10471), Tinkerbell (#10487)
  * Bug fixes
  - clusterctl: Ensure cert-manager objects get applied before
    other provider objects (#10469)
  - clusterctl: Ensure move uses mutated metadata when updating a
    target object (#10982)
  - clusterctl: Fix log in clusterctl move (#10540)
  - clusterctl: Handle a nil mutator by returning an error, not
    panicking (#10981)
  - clusterctl: Verify that there is a release for the tag
    (#10220)
  * Others
  - clusterctl: Add ionoscloud provider (#10767)
  - clusterctl: Add support for the linode-linode infrastructure
    provider to clusterctl (#10471)
  - clusterctl: Add Tinkerbell to the providers list (#10487)
  - clusterctl: Always run crd migration if possible to reduce
    conversion webhook usage (#10513)
  - clusterctl: Bump cert-manager to 1.14.5 (#10514)
  - clusterctl: Bump cert-manager to v1.15.0 (#10727)
  - clusterctl: Bump cert-manager to v1.15.1 (#10807)
  - clusterctl: Bump cert-manager to v1.15.2 (#10992)
  - clusterctl: Improve cert-manager shouldUpgrade (#10407)
  - clusterctl: Update Config generation to use inClusterConfig
    (#11006)
  - Testing: Allow control plane count to be configurable in
    clusterctl upgrade test. (#10584)
  - Testing: Support MachinePools without MachinePoolMachines in
    clusterctl upgrade test (#10498)
* Mon Aug 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.5:
  * Machine Controller should try to retrieve node on delete - fix
    unit test
  * bug: Machine Controller should try to retrieve node on delete
  * MachineSet should allow scale down operations to proceed
    when templates don't exist
  * Bump docker/docker to v25.0.6
  * test/framework: scale up should use allocatable memory
  * Ensure DockerMachinePool providerIDList is deterministic
  * test: prevent using Consistently for rollout checks
  * test/framework: Allow ScaleUp Deployment image to be customized
  * bump cert-manager to 1.15.2
  * Drop caBundle from CRDs
  * Allow ClusterCacheTracker to set CacheByObject
  * bug: When infrastructureRef is nil, set
    InfrastructureReadyCondition to true
  * Partially revert changes for ":bug: Cluster should be
    provisoned when cpRef and endpoint is set"
  * :seedling: Make ClusterResourceSet controller more predictable
  * :sparkles: Add QPS & burst options & flags for
    ClusterCacheTracker
  * Address comments
  * Fix race conditions
  * Address comments
  * Ensure CRS controller always add ownerReference to resources
  * test: use pause instead of nginx
  * test: use pause image for autoscaler tests
  * bug: Cluster should be provisoned when cpRef and endpoint is
    set
  * capd: fix nil pointer in dockermachinepool controller
  * book: Add missing kubeconfig file to deploy
    cloud-controller-manager on workload cluster
  * book: update Azure quick start for CAPZ v1.16
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.4:
  * Extend ControlPlane/Deployment/Pool builtin to include metadata
  * [release-1.7] ✨ Allow CAPBK to generate JoinConfiguration
    discovery kubeconfig (#10842)
  * bug: Patch helper should be able to patch non-spec objects
  * Extend cluster builtin to include UID
  * Bump to Go 1.22.5
  * [release-1.7] 🌱 Allow control plane provider to set endpoint
    (#10800)
  * bump cert-manager to 1.15.1
  * Bump to Go 1.22.4
  * docs: fix dead link in
    proposals/20210222-kubelet-authentication.md
  * 🐛 Correctly handle concurrent updates to
    ClusterResourceSetBinding
  * MD/MS topo reconciler: only add finalizer for owned MD/MS
  * Update quick-start.md
  * Update Proxmox quick-start docs
  * ✨ Add kubeadm v1beta4 types (#10709)
  * Deprioritize unknown NodeHealthy conditions for deletion
  * [release-1.7] :seedling: Add ionoscloud provider (#10769)
  * fix: delayed MHC replacement of unreachable nodes
  * fix(10661): volumes don't block deletion of unreachable nodes
  * Improve logs when machine is waiting for node
  * Ensure unhealthy machines get deletion priority
  * book: Fix comment on NodeStartupTimeout
  * :sparkles: Add remediation strategy support for MachineSet
  * seedling: MachineHealthCheck should take Machine's InfraReady
    condition for startup time
  * [release-1.7] 🌱 Improvements to ownerReferences and finalizers
    test (#10747)
* Sun Jun 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.3:
  * Bump to Go 1.21.11
  * update cert-manager to v1.15.0
  * fix broken kubebuilder link in old docs
  * Support ControlPlane variable overrides
  * docs: fix dead links
* Sun Jun 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package clusterctl: tool that handles the lifecycle of a
  Cluster API management cluster
